@@ -77,6 +77,7 @@ class Controller:
         self.loop = None
 
         self.msg_queue = queue.Queue()
+        self.logger = logging.getLogger(self.__class__.__name__)
 
         # we take teh runner if passed (mostly for testing)
         if runner is not None:
@@ -182,6 +183,8 @@ class Controller:
             if UP_TO_DATE:
                 self.log(f"task [red]{task.uid}[/red] is up to date, skipping it.")
                 return(True)
+        else:
+            self.log(f"adding [red]{task.uid}[/red] output is missing")
 
         self.log(f"adding [red]{task.uid}[/red]")
         self.log(" - cmd: {}".format( " ".join(task.get_command() ) ))
